# Distributed Lock

## Description

This package provides a simple implementation of distributed locks using Redis and Lua scripts.

## Installation

You can install this package via pip:

> pip install distributed-lock